Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/databases_update
   widgets/geo_data_sets
   widgets/dicty_express
   widgets/genes
   widgets/differential_expression
   widgets/go_browser
   widgets/kegg_pathways
   widgets/gene_set_enrichment
   widgets/cluster_analysis
   widgets/volcano_plot
   widgets/marker_genes
   widgets/annotate_projection